#include "Menu.h"

/**
 * @brief Menu ctor
 * @param x x position
 * @param y y position
 * @param width width of Buttons
 */
Menu::Menu(unsigned x, unsigned y, unsigned width)
:x(x), y(y), width(width), current_y(y) {
}

/**
 * @brief Menu dtor, frees contained buttons
 */
Menu::~Menu() {
    for(auto b : buttons) {
        delete b;
    }
}

/**
 * @brief Adds a new Button to the Menu
 * @param key SDL code for the key to activate Button
 * @param text text displayed on the Button
 * @param key_label sign for the key that activates the Button
 */
void Menu::add_button(unsigned key, std::string text, std::string key_label) {
    buttons.push_back(new Button(x, current_y, width, 60, key, text, key_label));
    current_y += 80;
}

/**
 * @brief Processes a mouseclick
 * @param mouse_x x position of click event
 * @param mouse_y y position of click event
 * @return index of button pressed (-1 if none)
 */
int Menu::click(unsigned mouse_x, unsigned mouse_y) const {
    for(unsigned i = 0; i < buttons.size(); i++) {
        if(buttons[i]->clicked(mouse_x, mouse_y)) {
            return i;
        }
    }
    return -1;
}

/**
 * @brief Processes a keypress
 * @param key SDL code of the key pressed
 * @return index of Button activated (-1 if none)
 */
int Menu::press(unsigned key) const {
    for(unsigned i = 0; i < buttons.size(); i++) {
        if(buttons[i]->pressed(key)) {
            return i;
        }
    }
    return -1;
}

/**
 * @brief Displays the Buttons on the screen using the global renderer
 */
void Menu::draw() const {
    for(auto b : buttons) {
        b->draw();
    }
}
