#include "TextDisplay.h"

/**
 * @brief TextDisplay ctor
 * @param y distance from top of the screen
 * @param filename text file to display
 */
TextDisplay::TextDisplay(unsigned y, std::string filename) : y(y), filename(filename) {
}

/**
 * @brief Displays contents of file until Back button is activated
 */
void TextDisplay::loop() {
    /* Back button creation */
    Menu help_menu(100, 600, 340);
    help_menu.add_button(SDLK_b, "Back", "B");
    
    /* Draw contents on screen, commit changes */
    display();
    help_menu.draw();
    SDL_RenderPresent(sdlRenderer);
    
    bool quit = false; /* Quit flag */
    while(SDL_WaitEvent(&ev) && !quit) { /* Regular event loop for Menu */
        int command = -1;
        switch(ev.type) {
            case SDL_QUIT:
                quit = true;
                break;
            case SDL_MOUSEBUTTONDOWN:
                if(ev.button.button == SDL_BUTTON_LEFT) {
                    command = help_menu.click(ev.button.x, ev.button.y);
                }
                break;
            case SDL_KEYDOWN:
                command = help_menu.press(ev.key.keysym.sym);
                break;
        }
        if(command == 0) {
            quit = true;
        }
    }
}

/**
 * @brief Displays contents of file using textColor
 */
void TextDisplay::display() const {
    std::ifstream in(filename.c_str());
    if(!in.is_open()) {
        std::cerr << "TextDisplay file not found" << std::endl;
        return;
    }
    else {
        unsigned current_y = y;
        unsigned h = 30; /* Line height */
        std::string temp; /* String that contains current line */
        while(getline(in, temp)) {
            /* In case of empty line read, just move position down one line 
             * without printing anything on the screen */
            if(temp != "") { 
                textColor(sdlRenderer, 110, current_y+h/2, h*.75, temp, 0x3494BAFF);
            }
            current_y += h;
        }
    }
}
